summaryrefslogtreecommitdiffstats
path: root/kwin-styles/icewm/icewm.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:25:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-11-07 20:25:05 -0600
commita5355f151396be579eba5838c7d8d93a43362cd7 (patch)
tree4660e8f56be211f2b4128e1591efc3dcfc0cf850 /kwin-styles/icewm/icewm.cpp
parent430baee366780c4f1eb2143a088590b91a957800 (diff)
downloadtdeartwork-a5355f151396be579eba5838c7d8d93a43362cd7.tar.gz
tdeartwork-a5355f151396be579eba5838c7d8d93a43362cd7.zip
Rename kwin to twin (part 1 of 2)
Diffstat (limited to 'kwin-styles/icewm/icewm.cpp')
-rw-r--r--kwin-styles/icewm/icewm.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/kwin-styles/icewm/icewm.cpp b/kwin-styles/icewm/icewm.cpp
index 47386962..4b9a064b 100644
--- a/kwin-styles/icewm/icewm.cpp
+++ b/kwin-styles/icewm/icewm.cpp
@@ -120,7 +120,7 @@ bool validframe = false;
bool useActiveShadow = false;
bool useInActiveShadow = false;
// KControl Settings - Read from kwinicewmrc config file or icewm theme
bool themeTitleTextColors = true; // Allow theme to set colors.
// kcontrol will have no effect
@@ -147,7 +147,7 @@ bool validPixmaps( TQPixmap* p[] )
// ThemeHandler class
//
// This class allows us to free dynamic memory upon being reset, or unloaded
// from kwin, so we don't leak big images everywhere, and handles the theme
// initialisation / destruction in general.
////////////////////////////////////////////////////////////////////////////////////////////
@@ -234,10 +234,10 @@ TQString ThemeHandler::reverseString( TQString s )
}
// This function reads the kwinicewmrc config file
void ThemeHandler::readConfig()
{
- KConfig conf("kwinicewmrc");
+ KConfig conf("twinicewmrc");
conf.setGroup("General");
themeName = conf.readEntry("CurrentTheme");
themeTitleTextColors = conf.readBoolEntry("ThemeTitleTextColors", true);
@@ -271,7 +271,7 @@ void ThemeHandler::initTheme()
// We use kconfig to read icewm config files...
// this is easy since icewm uses key=value pairs!
- KConfig config( locate("data", TQString("kwin/icewm-themes/") +
+ KConfig config( locate("data", TQString("twin/icewm-themes/") +
themeName + TQString("default.theme")) );
// Load specifics, or use IceWM defaults instead.
@@ -496,7 +496,7 @@ void ThemeHandler::freePixmapGroup( TQPixmap* p[] )
p[Active] = NULL;
p[InActive] = NULL;
} else
- qWarning("kwin-icewm: freePixmapGroup - invalid TQPixmap** 'p'\n");
+ qWarning("twin-icewm: freePixmapGroup - invalid TQPixmap** 'p'\n");
}
@@ -583,9 +583,9 @@ static void draw3DRect(TQPainter &pnt, TQColor &col, int x, int y, int w, int h,
void ThemeHandler::setPixmapButton( TQPixmap* p[], TQString s1, TQString s2)
{
if ( p[Active] )
- qWarning("kwin-icewm: setPixmap - should be null (1)\n");
+ qWarning("twin-icewm: setPixmap - should be null (1)\n");
if ( p[InActive] )
- qWarning("kwin-icewm: setPixmap - should be null (2)\n");
+ qWarning("twin-icewm: setPixmap - should be null (2)\n");
TQString str = locate("appdata", TQString("icewm-themes/")
+ themeName + s1 + "A" + s2);
@@ -682,13 +682,13 @@ void ThemeHandler::setPixmap( TQPixmap* p[], TQString s1, TQString s2,
bool stretch, bool stretchHoriz )
{
if ( p[Active] )
- qWarning("kwin-icewm: setPixmap - should be null (1)\n");
+ qWarning("twin-icewm: setPixmap - should be null (1)\n");
if ( p[InActive] )
- qWarning("kwin-icewm: setPixmap - should be null (2)\n");
+ qWarning("twin-icewm: setPixmap - should be null (2)\n");
- p[Active] = new TQPixmap( locate("data", TQString("kwin/icewm-themes/")
+ p[Active] = new TQPixmap( locate("data", TQString("twin/icewm-themes/")
+ themeName + s1 + "A" + s2) );
- p[InActive] = new TQPixmap( locate("data", TQString("kwin/icewm-themes/")
+ p[InActive] = new TQPixmap( locate("data", TQString("twin/icewm-themes/")
+ themeName + s1 + "I" + s2) );
// Stretch the pixmap if requested.
@@ -726,7 +726,7 @@ bool ThemeHandler::isFrameValid()
}
// Resets the theme, and re-clients all kwin's wrapped windows.
bool ThemeHandler::reset( unsigned long)
{
initialized = false;
@@ -825,7 +825,7 @@ void IceWMButton::drawButton(TQPainter *pnt)
pnt->drawPixmap(0, 0, *p, 0, 0, width, titleBarHeight);
}
} else
- qWarning("kwin-icewm: Can't paint a null pixmap button");
+ qWarning("twin-icewm: Can't paint a null pixmap button");
}
@@ -1028,7 +1028,7 @@ void IceWMClient::addClientButtons( const TQString& s )
break; */
case 'r':
// NOTE: kwin doesn't have toggleShade() in clients.h !
if ( validPixmaps(rollupPix) && !button[BtnRollup] )
{
button[BtnRollup] = new IceWMButton(this, "shade",
@@ -120,7 +120,7 @@ bool validframe = false;
bool useActiveShadow = false;
bool useInActiveShadow = false;
-// KControl Settings - Read from kwinicewmrc config file or icewm theme
+// KControl Settings - Read from twinicewmrc config file or icewm theme
bool themeTitleTextColors = true; // Allow theme to set colors.
// kcontrol will have no effect
@@ -147,7 +147,7 @@ bool validPixmaps( TQPixmap* p[] )
//
// This class allows us to free dynamic memory upon being reset, or unloaded
-// from kwin, so we don't leak big images everywhere, and handles the theme
+// from twin, so we don't leak big images everywhere, and handles the theme
// initialisation / destruction in general.
////////////////////////////////////////////////////////////////////////////////////////////
@@ -234,10 +234,10 @@ TQString ThemeHandler::reverseString( TQString s )
}
-// This function reads the kwinicewmrc config file
+// This function reads the twinicewmrc config file
void ThemeHandler::readConfig()
{
@@ -726,7 +726,7 @@ bool ThemeHandler::isFrameValid()
}
-// Resets the theme, and re-clients all kwin's wrapped windows.
+// Resets the theme, and re-clients all twin's wrapped windows.
bool ThemeHandler::reset( unsigned long)
{
@@ -1028,7 +1028,7 @@ void IceWMClient::addClientButtons( const TQString& s )
break; */
case 'r':
- // NOTE: kwin doesn't have toggleShade() in clients.h !
+ // NOTE: twin doesn't have toggleShade() in clients.h !
if ( validPixmaps(rollupPix) && !button[BtnRollup] )
{